@@ -51,6 +51,15 @@ Serializer = Callable[[ValuePayload], bytes]
 Deserializer = Callable[[bytes], ValuePayload]
 
 
+class CantDeserializeException(Exception):
+    """Exception indicating deserialization failed, and that caching
+    should proceed to re-generate a value
+
+    .. versionadded:: 1.2.0
+
+    """
+
+
 class CacheMutex(abc.ABC):
     """Describes a mutexing object with acquire and release methods.
 
@@ -85,6 +94,17 @@ class CacheMutex(abc.ABC):
 
         raise NotImplementedError()
 
+    @abc.abstractmethod
+    def locked(self) -> bool:
+        """Check if the mutex was acquired.
+
+        :return: true if the lock is acquired.
+
+        .. versionadded:: 1.1.2
+
+        """
+        raise NotImplementedError()
+
     @classmethod
     def __subclasshook__(cls, C):
         return hasattr(C, "acquire") and hasattr(C, "release")
@@ -141,7 +161,7 @@ class CacheBackend:
 
     """
 
-    serializer: Optional[Serializer] = None
+    serializer: Union[None, Serializer] = None
     """Serializer function that will be used by default if not overridden
     by the region.
 
@@ -149,7 +169,7 @@ class CacheBackend:
 
     """
 
-    deserializer: Optional[Deserializer] = None
+    deserializer: Union[None, Deserializer] = None
     """deserializer function that will be used by default if not overridden
     by the region.
 
@@ -435,8 +455,12 @@ class CacheBackend:
 
 
 class DefaultSerialization:
-    serializer: Optional[Serializer] = pickle.dumps
-    deserializer: Optional[Deserializer] = pickle.loads
+    serializer: Union[None, Serializer] = staticmethod(  # type: ignore
+        pickle.dumps
+    )
+    deserializer: Union[None, Deserializer] = staticmethod(  # type: ignore
+        pickle.loads
+    )
 
 
 class BytesBackend(DefaultSerialization, CacheBackend):
